@@ -16,10 +16,8 @@
 # PhiA is result of call to PhiA = vcovAdj(object, 0) in pbkrtest package
 # Phi is vcov(object) ## May not now be needed
 # lcoefs is contrast of interest
-# varlb is my already-computed value of lcoef' Phi lcoef = est variance of lcoef'betahat
-.KRdf.mer = function(PhiA, Phi, lcoefs, varlb) {
-  # I guess I'm supposed to use unadjusted varlb, as much as I'm inclined not to
-      vlb = sum(lcoefs * (Phi %*% lcoefs))
+.KRdf.mer = function(PhiA, Phi, lcoefs) {
+      vlb = sum(lcoefs * (Phi %*% lcoefs)) # unadjusted variance of l'beta
       Theta = Matrix(as.numeric(outer(lcoefs,lcoefs) / vlb), nrow=length(lcoefs))
       P = attr(PhiA,"P")
       W = attr(PhiA,"W")
